@@ -1,12 +1,13 @@
+import os
 import json
 import random
 import requests
-import os
 
 class UserAgent():
     def __init__(self, browser):
-        print(os.getcwd())
-        self.path = "src/swagenttools/user_agent_list/{}.txt".format(browser)
+        # find the current path of this file and open the user agent list
+        self.dirpath = os.path.dirname(os.path.abspath(__file__))
+        self.path = os.path.join(self.dirpath, "user_agent_list/{}.txt".format(browser))
         self.user_agents = open(self.path).read().splitlines()
 
     def random_agent(self):
